@@ -17,7 +17,7 @@ class QCticProvider(BaseProvider):
     ENV_HOST = "QCTIC_HOST"
     ENV_USERNAME = "QCTIC_USERNAME"
     ENV_PASSWORD = "QCTIC_PASSWORD"
-    ENV_TOKEN = "QCTIC_TOKEN"
+    ENV_TOKEN = "JUPYTERHUB_API_TOKEN"
 
     def __init__(self, *args, **kwargs):
         self._api = kwargs.pop("api")
